==> dl.php?src=linea21_1_8.zip: linea21/scale/quickbox.php <==
<?php
/**
 * Scale module
 * 
 * Provide information regarding latest administration tasks
 * 
 * @package linea21\core\scale
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->isSuperAdmin()) ReloadIndex('admin');
////////////

$qbx_module = _t('menu','scale');

if ($todo == 'add') {
  $result = $sql_object->DBSelect($req_quickbox_add);
  $qbx_liste = '';
  $nb = '';
  if ($result == 0) {
    $qbx_liste .= "<li>" . _t('divers','nodata') . "</li>";
  } else {
    if (count($result) >= 10) $nb = 10;
    else $nb = count($result);
    for($i = 0; $i < count($result); $i++) {
      $qbx_scale_title = formatText(cutText($result[$i]['scale_denomination'], 50), '2HTML');
      $qbx_liste .= "<li><a href=\"index.php?id=". $result[$i]['scale_id'] ."&amp;rub=$rub&amp;todo=det\" title=\""._t('divers','date_crea').": ".$result[$i]['scale_date_crea_display']."\">". $qbx_scale_title ."</a></li>\n";
    }
  }
  $qbx_h1 = $nb . _t('scale','qb_titleadd');
}

if ($todo == 'list' || $todo == 'det' || $todo == 'mod') {
  $result = $sql_object->DBSelect($req_quickbox_list);
  $qbx_liste = '';
  $nb = '';
  if ($result == 0) {
    $qbx_liste .= "<li>" . _t('divers','nodata') . "</li>";
  } else {
    if (count($result) >= 10) $nb = 10;
    else $nb = count($result);
    for($i = 0; $i < count($result); $i++) {
      $qbx_scale_title = formatText(cutText($result[$i]['scale_denomination'], 50), '2HTML');
      $qbx_liste .= "<li><a href=\"index.php?id=". $result[$i]['scale_id'] ."&amp;rub=$rub&amp;todo=det\" title=\""._t('divers','last_modify').": ".$result[$i]['scale_last_modify_display']."  ("._t('divers','date_crea').": ".$result[$i]['scale_date_crea_display'].") \">". $qbx_scale_title ."</a></li>\n";
    }
  }
  $qbx_h1 = $nb  . _t('scale','qb_titlemod');
}

if ($todo == 'sup') {
  $result = $sql_object->DBSelect($req_quickbox_sup);
  $qbx_liste = '';
  $nb = '';
  if ($result == 0) {
    $qbx_liste .= "<li>" . _t('divers','nodata') . "</li>";
  } else {
    if (count($result) >= 10) $nb = 10;
    else $nb = count($result);
    for($i = 0; $i < count($result); $i++) {
      $qbx_scale_title = formatText(cutText($result[$i]['scale_denomination'], 50), '2HTML');
      $qbx_liste .= "<li><a href=\"#\" title=\"" . _t('divers','date_sup') . " " . $result[$i]['scale_last_modify_display'] . " - (" . _t('divers','date_crea') . ": " . $result[$i]['scale_last_modify_display'] . ") \">" . $qbx_scale_title . "</a></li>\n";
    }
  }
  $qbx_h1 = $nb . _t('scale','qb_titlesup');
}
echo QuickBoxNow($qbx_module, $qbx_h1, $qbx_liste);
?>

==> dl.php?src=linea21_2_3_0.zip: linea21/scale/quickbox.php <==
<?php
/**
 * Scale module
 * 
 * Provide information regarding latest administration tasks
 * 
 * @package linea21\core\scale
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->isSuperAdmin()) ReloadIndex('admin');
////////////

$qbx_module = _t('menu','scale');

if ($todo == 'add') {
  $result = $sql_object->DBSelect($req_quickbox_add);
  $qbx_liste = '';
  $nb = '';
  if ($result == 0) {
    $qbx_liste .= "<li class=\"no-data\">" . _t('divers','nodata') . "</li>";
  } else {
    if (count($result) >= 10) $nb = 10;
    else $nb = count($result);
    for($i = 0; $i < count($result); $i++) {
      $qbx_scale_title = formatText(cutText($result[$i]['scale_denomination'], 50), '2HTML');
      $qbx_liste .= "<li><a href=\"index.php?id=". $result[$i]['scale_id'] ."&amp;rub=$rub&amp;todo=det\" title=\""._t('divers','date_crea').": ".$result[$i]['scale_date_crea_display']."\">". $qbx_scale_title ."</a></li>\n";
    }
  }
  $qbx_h1 = $nb . _t('scale','qb_titleadd');
}

if ($todo == 'list' || $todo == 'det' || $todo == 'mod') {
  $result = $sql_object->DBSelect($req_quickbox_list);
  $qbx_liste = '';
  $nb = '';
  if ($result == 0) {
    $qbx_liste .= "<li class=\"no-data\">" . _t('divers','nodata') . "</li>";
  } else {
    if (count($result) >= 10) $nb = 10;
    else $nb = count($result);
    for($i = 0; $i < count($result); $i++) {
      $qbx_scale_title = formatText(cutText($result[$i]['scale_denomination'], 50), '2HTML');
      $qbx_liste .= "<li><a href=\"index.php?id=". $result[$i]['scale_id'] ."&amp;rub=$rub&amp;todo=det\" title=\""._t('divers','last_modify').": ".$result[$i]['scale_last_modify_display']."  ("._t('divers','date_crea').": ".$result[$i]['scale_date_crea_display'].") \">". $qbx_scale_title ."</a></li>\n";
    }
  }
  $qbx_h1 = $nb  . _t('scale','qb_titlemod');
}

if ($todo == 'sup') {
  $result = $sql_object->DBSelect($req_quickbox_sup);
  $qbx_liste = '';
  $nb = '';
  if ($result == 0) {
    $qbx_liste .= "<li class=\"no-data\">" . _t('divers','nodata') . "</li>";
  } else {
    if (count($result) >= 10) $nb = 10;
    else $nb = count($result);
    for($i = 0; $i < count($result); $i++) {
      $qbx_scale_title = formatText(cutText($result[$i]['scale_denomination'], 50), '2HTML');
      $qbx_liste .= "<li><a href=\"#\" title=\"" . _t('divers','date_sup') . " " . $result[$i]['scale_last_modify_display'] . " - (" . _t('divers','date_crea') . ": " . $result[$i]['scale_last_modify_display'] . ") \">" . $qbx_scale_title . "</a></li>\n";
    }
  }
  $qbx_h1 = $nb . _t('scale','qb_titlesup');
}
echo QuickBoxNow($qbx_module, $qbx_h1, $qbx_liste);
?>
